@@ -11,6 +11,28 @@ missing imports / variables:
 	defaults, python_plus
 """
 
+# functions.
+def check_user(id, create=False):
+	user = syst3m.User(username=id)
+	response = user.check()
+	if not response.success:  return response
+	if response["success"] and not response["exists"] and create: 
+		response = user.create()
+		if not response.success: return response
+	return r3sponse.success(f"Successfully checked user [{id}].")
+def check_group(id, users=[], create=False, overwrite=False):
+	group = syst3m.Group(name=id, get_users=False)
+	response = group.check()
+	if not response.success: return response
+	if response["success"] and not response["exists"] and create: 
+		response = group.create(users=users)
+		if not response.success: return response
+	elif overwrite:
+		response = group.check_users(users=users)
+		if not response.success: return response
+	return r3sponse.success(f"Successfully checked group [{id}].")
+
+
 # the user object.
 class User(object):
 	# notes about the object
